@@ -8,7 +8,7 @@ from dependency_injector import providers
 from krules_core.base_functions.filters import Filter
 from krules_core.base_functions.processing import Process, SetPayloadProperty
 
-from krules_core import RuleConst
+from krules_core import RuleConst, ProcEventsLevel
 
 from krules_core.core import RuleFactory
 
@@ -40,11 +40,12 @@ subscribed_rules = []
 
 
 def test_filtered(router, subject):
-    os.environ["PUBLISH_PROCEVENTS"] = "0"
-    os.environ["PUBLISH_PROCEVENTS_FILTERS"] = "$[?(processed=true)]"
+    os.environ["PUBLISH_PROCEVENTS"] = str(ProcEventsLevel.FULL)
+    os.environ["PUBLISH_PROCEVENTS_FILTERS"] = "$[?(passed=true)]"
 
     proc_events_rx_factory.subscribe(
-        on_next=lambda x: publish_proc_events_filtered(x, "$[?(processed=true)]", lambda match: match is not None, debug=True))
+        on_next=lambda x: publish_proc_events_filtered(x, "$[?(passed=true)]", lambda match: match is not None,
+                                                       debug=True))
 
     from pprint import pprint
 
@@ -82,6 +83,3 @@ def test_filtered(router, subject):
 
     assert "check-even-value" in subscribed_rules
     assert "check-odd-value" not in subscribed_rules
-
-
-from rx import from_future
\ No newline at end of file
